@@ -192,29 +192,30 @@ def create_experiment_function(start_trial_number):
 
         print('    values = []', file=f)
         for k in inputs:
-            print('    ', file=f)
+            print('        ', file=f)
+            print('        # ' + k, file=f)
             t,v = inputs[k]
             if v.find('-') > 0:
                 if t == 'float':
-                    print('    s = trial.suggest_uniform("'+k+'", 0, 1)', file=f)
-                    print('    s = s * ('+v[v.find('-') + 1:]+' - '+v[:v.find('-')]+') + '+v[:v.find('-')]+'', file=f)
-                    print('    values.append(s)', file=f)
-                    print('    # Alternative:', file=f)
-                    print('    #values.append(trial.suggest_uniform("'+k+'", '+v[:v.find('-')]+','+v[v.find('-')+1:]+')'+')', file=f)
+                    print('        s = trial.suggest_uniform("'+k+'", 0, 1)', file=f)
+                    print('        s = s * ('+v[v.find('-') + 1:]+' - '+v[:v.find('-')]+') + '+v[:v.find('-')]+'', file=f)
+                    print('        values.append(s)', file=f)
+                    print('        # Alternative:', file=f)
+                    print('        #values.append(trial.suggest_uniform("'+k+'", '+v[:v.find('-')]+','+v[v.find('-')+1:]+')'+')', file=f)
                 else:
-                    print('    s = trial.suggest_uniform("'+k+'", 0, 1)', file=f)
-                    print('    s = s * (1 + '+v[v.find('-') + 1:]+' - '+v[:v.find('-')]+') + '+v[:v.find('-')]+'', file=f)
-                    print('    values.append(int(s))', file=f)
-                    print('    # Alternative:', file=f)
-                    print('    #values.append(trial.suggest_int("'+k+'", '+v[:v.find('-')]+','+v[v.find('-')+1:]+')'+')', file=f)
+                    print('        s = trial.suggest_uniform("'+k+'", 0, 1)', file=f)
+                    print('        s = s * (1 + '+v[v.find('-') + 1:]+' - '+v[:v.find('-')]+') + '+v[:v.find('-')]+'', file=f)
+                    print('        values.append(int(s))', file=f)
+                    print('        # Alternative:', file=f)
+                    print('        #values.append(trial.suggest_int("'+k+'", '+v[:v.find('-')]+','+v[v.find('-')+1:]+')'+')', file=f)
             elif v.find(',') > 0:
-                print('    s = trial.suggest_uniform("' + k + '", 0, 1)', file=f)
-                print('    s = s * (1 + ' + str(v.count(',')) + ')', file=f)
-                print('    values.append(['+v+'][s])', file=f)
-                print('    # Alternative:', file=f)
-                print('    #values.append(trial.suggest_categorical("'+k+'", ['+v+'])' +')', file=f)
+                print('        s = trial.suggest_uniform("' + k + '", 0, 1)', file=f)
+                print('        s = s * (1 + ' + str(v.count(',')) + ')', file=f)
+                print('        values.append(['+v+'][s])', file=f)
+                print('        # Alternative:', file=f)
+                print('        #values.append(trial.suggest_categorical("'+k+'", ['+v+'])' +')', file=f)
             else:
-                print('    values.append('+v+') # ' + k, file=f)
+                print('        values.append('+v+')', file=f)
 
         end_text = """
                 result_branch = 'rXXXBRANCHNAMEXXX_'+str(time.time_ns())
@@ -394,6 +395,7 @@ def create_optuna_directories(input_branch_name, vc):
     print('GIT CLEAN -F')
     subprocess.call('git clean -f'.split(' '))
     subprocess.call('git reset --hard'.split(' '))
+    subprocess.call('rm -fR tmp_*'.split(' '))
     os.chdir(cwd)
 
     metric_path = '../' + folder_name + '_MetricGetter'
